pitchtools.NumberedChromaticPitchClassSet
=========================================

.. autoclass:: abjad.tools.pitchtools.NumberedChromaticPitchClassSet
   :members:
   :undoc-members:
   :show-inheritance:
